@@ -27,6 +27,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
+#include <SDL.h>
 
 #include "pcsound.h"
 #include "timer.h"
@@ -53,6 +54,7 @@
 
 static int savescore;		/* save players score on restart  */
 static BOOL ghost;		/* ghost display flag             */
+static starting_level = 0;
 
 static char helptxt[] =
 "\n"
@@ -66,7 +68,9 @@ static char helptxt[] =
 "        -s :  single player\n"
 "        -c :  single player against computer\n"
 "        -x :  enable missiles\n"
-"        -q :  begin game with sound off\n"
+"        -q :  begin game with sound off (default)\n"
+"        -p :  turn sound on\n"
+"        -g#:  start at level #\n"
 "\n"
 "Video:\n"
 "        -f :  fullscreen\n"
@@ -1034,7 +1038,9 @@ void swrestart()
 		++gamenum;
 		savescore = ob->ob_score;
 	} else {
-		gamenum = 0;
+		// gamenum = 0;
+                // allow variable start level -- Jesse
+                gamenum = starting_level;
 		savescore = 0;
 
 		// sh 28/10/2001: go back to the title screen
@@ -1097,6 +1103,7 @@ void swinit(int argc, char *argv[])
 	
 	// sdh 29/10/2001: load config from configuration file
 
+        soundflg = 1;      // assume off by default
 	swloadconf();
 
 	for (i=1; i<argc; ++i) {
@@ -1108,10 +1115,17 @@ void swinit(int argc, char *argv[])
 			c = 1;
 		else if (!strcasecmp(argv[i], "-f"))
 			vid_fullscreen = 1;
+                else if (!strncasecmp(argv[i], "-g", 2))
+                {
+                    sscanf(& (argv[i][2]), "%d", &starting_level);
+                    gamenum = starting_level;
+                }
 		else if (!strcasecmp(argv[i], "-2"))
 			vid_double_size = 1;
 		else if (!strcasecmp(argv[i], "-q"))
 			soundflg = 1;
+                else if (!strcasecmp(argv[i], "-p"))
+                        soundflg = 0;
 		else if (!strcasecmp(argv[i], "-x"))
 			conf_missiles = 1;
 		else 
@@ -1177,6 +1191,9 @@ void swinit(int argc, char *argv[])
 
 	// sdh 28/10/2001: moved getmode into swmain
 	// sdh 27/10/2001: moved all level init stuff into swinitlevel
+
+        // make mouse disappear
+        SDL_ShowCursor(SDL_DISABLE);
 }
 
 //---------------------------------------------------------------------------
